timeintervaltools.compute_depth_of_intervals
============================================

.. autofunction:: abjad.tools.timeintervaltools.compute_depth_of_intervals.compute_depth_of_intervals
   :noindex:
